@@ -1,5 +1,5 @@
 from jupyter_server.base.handlers import JupyterHandler
-from urllib.parse import urljoin
+from jupyter_server.utils import url_path_join
 import tornado.web
 
 
@@ -12,11 +12,13 @@ class ParametersHandler(JupyterHandler):
         redirect = params.pop("redirect", "/lab")
 
         # Send parameter values to server_params
-        server_params = self.settings["server_params"]
+        server_params = self.settings["server_parameters"]
         try:
             await server_params.handle_parameters(params)
         except Exception:
             self.log.exception("Unable to handle parameters")
 
         # Perform redirect
-        self.redirect(urljoin(self.base_url, redirect))
+        destination = url_path_join(self.base_url, redirect)
+        self.log.debug(f"Redirecting to {destination}")
+        self.redirect(destination)
